Index: /branches/release-34/tmpl/cms/dialog/publishing_profile.tmpl
===================================================================
--- /branches/release-34/tmpl/cms/dialog/publishing_profile.tmpl (revision 1877)
+++ /branches/release-34/tmpl/cms/dialog/publishing_profile.tmpl (revision 1880)
@@ -64,5 +64,5 @@
                 <li>
                     <input type="radio" id="dynamicity-partialasync" name="dynamicity" value="async_partial" <mt:if name="dynamicity" eq="async_partial"> checked="checked"</mt:if>/>
-                    <label for="dynamicity-partialasync"><__trans phrase="High Priority Static Publishing"> <span class="hint"><__trans phrase="Publish main index template and all individual archive templates statically, and publish all other files asynchronously."></span></label>
+                    <label for="dynamicity-partialasync"><__trans phrase="High Priority Static Publishing"> <span class="hint"><__trans phrase="Publish main index template and all entry/page archives statically. Publish all other files in the background."></span></label>
                 </li>
                 <li>

Index: /branches/release-34/lib/MT/CMS/Blog.pm
===================================================================
--- /branches/release-34/lib/MT/CMS/Blog.pm (revision 1877)
+++ /branches/release-34/lib/MT/CMS/Blog.pm (revision 1880)
@@ -1853,6 +1853,6 @@
         foreach my $tmpl_map (@tmpl_maps) {
             if ($dcty eq 'async_partial') {
-                # build the preferred archive type synchronously
-                if (($tmpl_map->archive_type eq $pref_at) &&
+                # build the preferred individual/page archives synchronously
+                if (($tmpl_map->archive_type =~ m/^(Individual|Page)$/) &&
                     ($tmpl_map->is_preferred)) {
                     $tmpl_map->build_type(MT::PublishOption::ONDEMAND());